@@ -111,11 +111,11 @@ class PatchworkPublisher(Component):
 
         return payload
 
-    def _build_task(self, payload: Any, meta: Mapping, cause: Task = None):
+    def _build_task(self, payload: Any, meta: Mapping, cause: Task = None, task_type: str = None):
         meta = dict(meta)
         task = Task()
         task.uuid = str(uuid.uuid4())
-        task.task_type = payload.__class__.__name__
+        task.task_type = task_type or payload.__class__.__name__
 
         if cause is not None:
             task.correlation_id = cause.correlation_id or cause.uuid
@@ -291,8 +291,8 @@ class AsyncPublisher(PatchworkPublisher):
 
         self.loop = loop
 
-    async def send(self, payload: Any, *, timeout: float = None, cause: Task = None, **meta):
-        task = self._build_task(payload, meta, cause=cause)
+    async def send(self, payload: Any, *, timeout: float = None, cause: Task = None, task_type: str = None, **meta):
+        task = self._build_task(payload, meta, cause=cause, task_type=task_type)
         await self.send_task(task, timeout=timeout)
         return task
 
